import requests
from datetime import datetime


class PLN_FX:
    def __init__(self):
        self.url = "https://api.nbp.pl/api/exchangerates/rates/A/EUR"

    def get_year(self, year):
        today = datetime.now()
        start_year = datetime(int(year), 1, 1)
        end_year = datetime(int(year), 12, 31)
        end_year = today if end_year > today else end_year
        url = f"{self.url}/{start_year.date()}/{end_year.date()}/"
        response = requests.get(url)
        if not response.status_code == 200:
            raise Exception("National Bank of Poland API not reachable.")
        else:
            data = response.json()
            data = data.get("rates", [])
            data = [{"date": x["effectiveDate"], "rate": x["mid"]} for x in data]
            return data

    def get_date(self, date):
        date = datetime.strptime(date, "%Y-%m-%d")
        data = self.get_year(date.year)
        for x in data:
            if x["date"] == str(date.date()):
                return x
                break
        return None


if __name__ == "__main__":
    fx = PLN_FX()

    year_rate = fx.get_year("2022")
    print("\n year_rate: ", year_rate)

    day_rate = fx.get_date("2022-01-03")
    print("\n day_rate: ", day_rate)



from setuptools import setup, find_packages
import codecs
import os

here = os.path.abspath(os.path.dirname(__file__))

with codecs.open(os.path.join(here, "README.md"), encoding="utf-8") as fh:
    long_description = "\n" + fh.read()

VERSION             = '0.0.7'
DESCRIPTION         = 'Get rates from the Polish National Bank (Narodowy Bank Polski)'
LONG_DESCRIPTION    = 'A package that allows you to retrieve the mid rate used for Accounting from the API directly of the Polish National Bank'

setup(
    name="pln_fx",
    version=VERSION,
    author="Stephan Semerad",
    author_email="<stephan.semerad@gmail.com>",
    description=DESCRIPTION,
    long_description_content_type="text/markdown",
    long_description=long_description,
    packages=find_packages(),
    install_requires=['requests'],
    keywords=['python', 'poland', 'fx', 'exchange rates', 'exchange', 'pln', 'plnfx', 'zloty'],
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ]
)
